# Support functions for the labs in the TSBB15 course


## Some known issues

If you are using conda on windows you might get an error:
> tempfile.tif: Cannot read TIFF header.

If thats the case, uninstall libtiff (conda uninstall libtiff)
and reinstall it. (this will also require you to reinstall pillow)
